summaryrefslogtreecommitdiffstats
path: root/test/cache.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/cache.c')
-rw-r--r--test/cache.c48
1 files changed, 22 insertions, 26 deletions
diff --git a/test/cache.c b/test/cache.c
index e03525b..437dfc9 100644
--- a/test/cache.c
+++ b/test/cache.c
@@ -14415,13 +14415,13 @@ check_resize_entry(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, (LARGE_ENTRY_SIZE / 4));
+ result = H5C_resize_entry((void *)entry_ptr, (LARGE_ENTRY_SIZE / 4));
if ( result < 0 ) {
pass = FALSE;
HDsnprintf(msg, (size_t)128,
- "H5C_resize_pinned_entry() reports failure 1.");
+ "H5C_resize_entry() reports failure 1.");
failure_mssg = msg;
}
@@ -14475,13 +14475,13 @@ check_resize_entry(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, LARGE_ENTRY_SIZE);
+ result = H5C_resize_entry((void *)entry_ptr, LARGE_ENTRY_SIZE);
if ( result < 0 ) {
pass = FALSE;
HDsnprintf(msg, (size_t)128,
- "H5C_resize_pinned_entry() reports failure 2.");
+ "H5C_resize_entry() reports failure 2.");
failure_mssg = msg;
}
@@ -14823,13 +14823,13 @@ check_resize_entry(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, (LARGE_ENTRY_SIZE / 4));
+ result = H5C_resize_entry((void *)entry_ptr, (LARGE_ENTRY_SIZE / 4));
if ( result < 0 ) {
pass = FALSE;
HDsnprintf(msg, (size_t)128,
- "H5C_resize_pinned_entry() reports failure 3.");
+ "H5C_resize_entry() reports failure 3.");
failure_mssg = msg;
}
@@ -14885,13 +14885,13 @@ check_resize_entry(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, LARGE_ENTRY_SIZE);
+ result = H5C_resize_entry((void *)entry_ptr, LARGE_ENTRY_SIZE);
if ( result < 0 ) {
pass = FALSE;
HDsnprintf(msg, (size_t)128,
- "H5C_resize_pinned_entry() reports failure 4.");
+ "H5C_resize_entry() reports failure 4.");
failure_mssg = msg;
}
@@ -16842,7 +16842,7 @@ check_expunge_entry_errs(void)
/*-------------------------------------------------------------------------
* Function: check_resize_entry_errs()
*
* Purpose: Verify that invalid calls to H5C_resize_pinned_entry()
* generates errors as expected.
*
* Return: void
@@ -16850,10 +16850,6 @@ check_expunge_entry_errs(void)
* Programmer: John Mainzer
* 7/7/06
*
- * Modifications:
- *
- * None.
- *
*-------------------------------------------------------------------------
*/
@@ -16870,11 +16866,11 @@ check_resize_entry_errs(void)
pass = TRUE;
/* Allocate a cache, protect an entry, and then call
* H5C_resize_pinned_entry() to resize it -- this should fail.
*
* Unprotect the the entry with the pinned flag, and then call
* H5C_resize_pinned_entry() again with new size of zero.
* This should fail too.
*
* Finally, unpin the entry and destroy the cache.
* This should succeed.
@@ -16895,13 +16891,13 @@ check_resize_entry_errs(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, (size_t)1);
+ result = H5C_resize_entry((void *)entry_ptr, (size_t)1);
- if ( result > 0 ) {
+ if ( result < 0 ) {
pass = FALSE;
failure_mssg =
- "Call to H5C_resize_pinned_entry on a protected entry succeeded.\n";
+ "Call to H5C_resize_entry on a protected entry failed.\n";
} else {
@@ -16912,13 +16908,13 @@ check_resize_entry_errs(void)
if ( pass ) {
- result = H5C_resize_pinned_entry((void *)entry_ptr, (size_t)0);
+ result = H5C_resize_entry((void *)entry_ptr, (size_t)0);
- if ( result > 0 ) {
+ if ( result >= 0 ) {
pass = FALSE;
failure_mssg =
- "Call to H5C_resize_pinned_entry with 0 new size succeeded.\n";
+ "Call to H5C_resize_entry with 0 new size succeeded.\n";
} else {
@@ -21242,7 +21238,7 @@ check_auto_cache_resize(void)
protect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 10);
unprotect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 10, NO_CHANGE,
H5C__PIN_ENTRY_FLAG);
- resize_pinned_entry(cache_ptr, VARIABLE_ENTRY_TYPE, 10, 2 * 1024);
+ resize_entry(file_ptr, VARIABLE_ENTRY_TYPE, 10, 2 * 1024, TRUE);
if ( ( pass ) &&
( ( ( cache_ptr->max_cache_size != (6 * 1024) ) ||
@@ -21260,7 +21256,7 @@ check_auto_cache_resize(void)
if ( pass ) {
- resize_pinned_entry(cache_ptr, VARIABLE_ENTRY_TYPE, 10, 10 * 1024);
+ resize_entry(file_ptr, VARIABLE_ENTRY_TYPE, 10, 10 * 1024, TRUE);
if ( ( pass ) &&
( ( ( cache_ptr->max_cache_size != (13 * 1024) ) ||
@@ -21281,7 +21277,7 @@ check_auto_cache_resize(void)
protect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 11);
unprotect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 11, NO_CHANGE,
H5C__PIN_ENTRY_FLAG);
- resize_pinned_entry(cache_ptr, VARIABLE_ENTRY_TYPE, 11, 10 * 1024);
+ resize_entry(file_ptr, VARIABLE_ENTRY_TYPE, 11, 10 * 1024, TRUE);
if ( ( pass ) &&
( ( ( cache_ptr->max_cache_size != (22 * 1024) ) ||
@@ -21302,7 +21298,7 @@ check_auto_cache_resize(void)
protect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 12);
unprotect_entry(file_ptr, VARIABLE_ENTRY_TYPE, 12, NO_CHANGE,
H5C__PIN_ENTRY_FLAG);
- resize_pinned_entry(cache_ptr, VARIABLE_ENTRY_TYPE, 12, 10 * 1024);
+ resize_entry(file_ptr, VARIABLE_ENTRY_TYPE, 12, 10 * 1024, TRUE);
if ( ( pass ) &&
( ( ( cache_ptr->max_cache_size != (22 * 1024) ) ||
@@ -16842,7 +16842,7 @@ check_expunge_entry_errs(void)
* Function: check_resize_entry_errs()
*
- * Purpose: Verify that invalid calls to H5C_resize_pinned_entry()
+ * Purpose: Verify that invalid calls to H5C_resize_entry()
* generates errors as expected.
*
@@ -16870,11 +16866,11 @@ check_resize_entry_errs(void)
pass = TRUE;
/* Allocate a cache, protect an entry, and then call
- * H5C_resize_pinned_entry() to resize it -- this should fail.
+ * H5C_resize_entry() to resize it -- this should succeed.
*
* Unprotect the the entry with the pinned flag, and then call
@@ -16870,11 +16866,11 @@ check_resize_entry_errs(void)
*
* Unprotect the the entry with the pinned flag, and then call
- * H5C_resize_pinned_entry() again with new size of zero.
- * This should fail too.
+ * H5C_resize_entry() again with new size of zero.
+ * This should fail.
*
* Finally, unpin the entry and destroy the cache.